from django.utils.functional import cached_property
from embed_video.templatetags.embed_video_tags import VideoNode
from wagtail.core.blocks import ChooserBlock


class EmbedVideoChooserBlock(ChooserBlock):
    @cached_property
    def target_model(self):
        from wagtail_embed_videos.models import get_embed_video_model

        return get_embed_video_model()

    @cached_property
    def widget(self):
        from wagtail_embed_videos.widgets import AdminEmbedVideoChooser

        return AdminEmbedVideoChooser

    def render_basic(self, value, context=None):
        if value:
            return VideoNode.embed(value.url, size="medium")
        else:
            return ""

    # TODO: implement get_comparison_class

    class Meta:
        icon = "media"



# coding: utf-8

from django import forms
from django.forms.models import modelform_factory
from django.utils.translation import gettext as _
from wagtail.admin import widgets
from wagtail.admin.forms.collections import (
    BaseCollectionMemberForm, collection_member_permission_formset_factory)
from wagtail.images.edit_handlers import AdminImageChooser

from wagtail_embed_videos.models import EmbedVideo
from wagtail_embed_videos.permissions import \
    permission_policy as embed_videos_permission_policy


# Callback to allow us to override the default form field for the embed video file field
def formfield_for_dbfield(db_field, **kwargs):
    # For all other fields, just call its formfield() method.
    return db_field.formfield(**kwargs)


class BaseEmbedVideoForm(BaseCollectionMemberForm):
    permission_policy = embed_videos_permission_policy


def get_embed_video_form(model):
    fields = model.admin_form_fields
    if "collection" not in fields:
        # force addition of the 'collection' field, because leaving it out can
        # cause dubious results when multiple collections exist (e.g adding the
        # document to the root collection where the user may not have permission) -
        # and when only one collection exists, it will get hidden anyway.
        fields = list(fields) + ["collection"]

    return modelform_factory(
        model,
        form=BaseEmbedVideoForm,
        fields=fields,
        formfield_callback=formfield_for_dbfield,
        widgets={
            "tags": widgets.AdminTagWidget,
            "thumbnail": AdminImageChooser,
        },
    )


class EmbedVideoInsertionForm(forms.Form):
    alt_text = forms.CharField()


GroupEmbedVideoPermissionFormSet = collection_member_permission_formset_factory(
    EmbedVideo,
    [
        ("add_embedvideo", _("Add"), _("Add/edit embed videos you own")),
        ("change_embedvideo", _("Edit"), _("Edit any embed video")),
    ],
    "wagtail_embed_videos/permissions/includes/embedvideo_permissions_formset.html",
)



# Generated by Django 2.2.24 on 2021-11-02 12:00

import django.db.models.deletion
import wagtail.core.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0041_group_collection_permissions_verbose_name_plural"),
        ("wagtail_embed_videos", "0002_auto_20180822_0945"),
    ]

    operations = [
        migrations.AddField(
            model_name="embedvideo",
            name="collection",
            field=models.ForeignKey(
                default=wagtail.core.models.get_root_collection_id,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="wagtailcore.Collection",
                verbose_name="collection",
            ),
        ),
    ]



import sys

from django.conf import settings
from django.test import TestCase
from mock_django.models import ModelMock
from wagtail.images.models import get_image_model

from wagtail_embed_videos.models import EmbedVideo, create_thumbnail


class EmbedVideoTestCase(TestCase):
    def setUp(self):
        pass

    def test_video_image_model(self):
        """Image model is the default Wagtail model"""
        # Remove module from cache
        # (https://docs.python.org/3/reference/import.html#the-module-cache)
        try:
            del sys.modules["wagtail_embed_videos.models"]
        except KeyError:
            pass  # Nothing to do

        # Thumbnail model is set dynamically at import.
        from wagtail_embed_videos.models import image_model_name

        self.assertEqual(image_model_name, "wagtailimages.Image")

    def test_custom_image_model(self):
        """Image model is a custom model"""
        with self.settings(WAGTAILIMAGES_IMAGE_MODEL="testapp.CustomImage"):
            try:
                del sys.modules["wagtail_embed_videos.models"]
            except KeyError:
                pass  # Nothing to do

            from wagtail_embed_videos.models import image_model_name

            self.assertEqual(settings.WAGTAILIMAGES_IMAGE_MODEL, "testapp.CustomImage")
            self.assertEqual(image_model_name, "testapp.CustomImage")

    def test_create_thumbnail(self):
        """Fetch a thumbnail from a video service."""
        video = ModelMock(EmbedVideo)

        video.url = "https://www.youtube.com/watch?v=-YGDyPAwQz0"
        video.title = "Test title"
        create_thumbnail(video)
        Image = get_image_model()

        self.assertEqual("Test title", video.thumbnail.title)
        self.assertIn("video-thumbnail", [tag.name for tag in video.thumbnail.tags.all()])
        self.assertIsInstance(video.thumbnail, Image)



# Generated by Django 2.0.8 on 2018-08-22 09:45

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtail_embed_videos", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="embedvideo",
            name="uploaded_by_user",
            field=models.ForeignKey(
                blank=True,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]



# coding: utf-8

import certifi
import requests
import urllib3 as ul
from django.conf import settings
from django.core.files import File
from django.core.files.temp import NamedTemporaryFile
from django.db import models
from django.urls import reverse
from django.utils.translation import gettext_lazy as _
from embed_video.backends import VideoDoesntExistException, detect_backend
from embed_video.fields import EmbedVideoField
from taggit.managers import TaggableManager
from wagtail.admin.models import get_object_usage
from wagtail.core.models import CollectionMember
from wagtail.images import get_image_model, get_image_model_string
from wagtail.search import index
from wagtail.search.queryset import SearchableQuerySetMixin

YOUTUBE_RESOLUTIONS = ["maxresdefault.jpg", "sddefault.jpg", "mqdefault.jpg"]


class EmbedVideoQuerySet(SearchableQuerySetMixin, models.QuerySet):
    pass


def create_thumbnail(model_instance):
    # CREATING IMAGE FROM THUMBNAIL
    backend = detect_backend(model_instance.url)
    try:
        thumbnail_url = backend.get_thumbnail_url()
    except VideoDoesntExistException:
        return

    if backend.__class__.__name__ == "YoutubeBackend":
        if thumbnail_url.endswith("hqdefault.jpg"):
            for resolution in YOUTUBE_RESOLUTIONS:
                temp_thumbnail_url = thumbnail_url.replace("hqdefault.jpg", resolution)
                if int(requests.head(temp_thumbnail_url).status_code) < 400:
                    thumbnail_url = temp_thumbnail_url
                    break

    http = ul.PoolManager(cert_reqs="CERT_REQUIRED", ca_certs=certifi.where())

    img_temp = NamedTemporaryFile(suffix=".jpg", delete=False)
    img_temp.write(http.request("GET", thumbnail_url).data)
    img_temp.flush()

    image = get_image_model()(title=model_instance.title)
    image.file.save(model_instance.title + ".jpg", File(img_temp))

    model_instance.thumbnail = image
    model_instance.save()


class AbstractEmbedVideo(CollectionMember, index.Indexed, models.Model):
    title = models.CharField(max_length=255, verbose_name=_("title"))
    url = EmbedVideoField()
    thumbnail = models.ForeignKey(
        get_image_model_string(),
        verbose_name=_("thumbnail"),
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
    )
    created_at = models.DateTimeField(verbose_name=_("created at"), auto_now_add=True, db_index=True)
    uploaded_by_user = models.ForeignKey(
        settings.AUTH_USER_MODEL,
        verbose_name=_("uploaded by user"),
        null=True,
        blank=True,
        editable=False,
        on_delete=models.SET_NULL,
    )

    tags = TaggableManager(help_text=None, blank=True, verbose_name=_("tags"))

    objects = EmbedVideoQuerySet.as_manager()

    def get_usage(self):
        return get_object_usage(self)

    @property
    def usage_url(self):
        return reverse("wagtail_embed_videos:embed_video_usage", args=(self.id,))

    search_fields = CollectionMember.search_fields + [
        index.SearchField("title", partial_match=True, boost=10),
        index.AutocompleteField("title"),
        index.FilterField("title"),
        index.RelatedFields(
            "tags",
            [
                index.SearchField("name", partial_match=True, boost=10),
                index.AutocompleteField("name"),
            ],
        ),
        index.FilterField("uploaded_by_user"),
    ]

    def __str__(self):
        return self.title

    @property
    def default_alt_text(self):
        # by default the alt text field (used in rich text insertion) is populated
        # from the title. Subclasses might provide a separate alt field, and
        # override this
        return self.title

    def is_editable_by_user(self, user):
        from wagtail_embed_videos.permissions import permission_policy

        return permission_policy.user_has_permission_for_instance(user, "change", self)

    def save(self, *args, **kwargs):
        super().save(*args, **kwargs)
        if not self.thumbnail:
            create_thumbnail(self)

    class Meta:
        abstract = True


class EmbedVideo(AbstractEmbedVideo):
    admin_form_fields = (
        "title",
        "url",
        "thumbnail",
        "collection",
        "tags",
    )

    class Meta:
        verbose_name = _("embed video")
        verbose_name_plural = _("embed videos")



from django.urls import path

from wagtail_embed_videos.views import chooser, embed_videos

app_name = "wagtail_embed_videos"

urlpatterns = [
    path("", embed_videos.index, name="index"),
    path("<int:embed_video_id>/", embed_videos.edit, name="edit"),
    path("<int:embed_video_id>/delete/", embed_videos.delete, name="delete"),
    path("add/", embed_videos.add, name="add"),
    path("usage/<int:embed_video_id>/", embed_videos.usage, name="embed_video_usage"),
    path("chooser/", chooser.chooser, name="chooser"),
    path("chooser/<int:embed_video_id>/", chooser.embed_video_chosen, name="embed_video_chosen"),
    path("chooser/upload/", chooser.chooser_upload, name="chooser_upload"),
]



from django.conf import settings
from django.core.paginator import Paginator
from wagtail.admin.auth import PermissionPolicyChecker, permission_denied
from django.shortcuts import get_object_or_404, redirect
from django.template.response import TemplateResponse
from django.urls import reverse
from django.utils.translation import gettext as _
from django.views.decorators.vary import vary_on_headers
from wagtail.admin import messages
from wagtail.admin.forms.search import SearchForm
from wagtail.admin.models import popular_tags_for_model
from wagtail.core.models import Collection
from wagtail.search import index as search_index

from wagtail_embed_videos import get_embed_video_model
from wagtail_embed_videos.forms import get_embed_video_form
from wagtail_embed_videos.permissions import permission_policy

permission_checker = PermissionPolicyChecker(permission_policy)

INDEX_PAGE_SIZE = getattr(settings, "WAGTAILEMBEDVIDEOS_INDEX_PAGE_SIZE", 20)
USAGE_PAGE_SIZE = getattr(settings, "WAGTAILEMBEDVIDEOS_USAGE_PAGE_SIZE", 20)


@permission_checker.require_any("add", "change", "delete")
@vary_on_headers("X-Requested-With")
def index(request):
    EmbedVideo = get_embed_video_model()

    # Get embed videos (filtered by user permission)
    embed_videos = permission_policy.instances_user_has_any_permission_for(request.user, ["change", "delete"]).order_by(
        "-created_at"
    )

    # Search
    query_string = None
    if "q" in request.GET:
        form = SearchForm(request.GET, placeholder=_("Search embed videos"))
        if form.is_valid():
            query_string = form.cleaned_data["q"]

            embed_videos = embed_videos.search(query_string)
    else:
        form = SearchForm(placeholder=_("Search embed videos"))

    # Filter by collection
    current_collection = None
    collection_id = request.GET.get("collection_id")
    if collection_id:
        try:
            current_collection = Collection.objects.get(id=collection_id)
            embed_videos = embed_videos.filter(collection=current_collection)
        except (ValueError, Collection.DoesNotExist):
            pass

    # Filter by tag
    current_tag = request.GET.get("tag")
    if current_tag:
        try:
            embed_videos = embed_videos.filter(tags__name=current_tag)
        except (AttributeError):
            current_tag = None

    paginator = Paginator(embed_videos, per_page=INDEX_PAGE_SIZE)
    embed_videos = paginator.get_page(request.GET.get("p"))

    collections = permission_policy.collections_user_has_any_permission_for(request.user, ["add", "change"])
    if len(collections) < 2:
        collections = None
    else:
        collections = Collection.order_for_display(collections)

    # Create response
    if request.is_ajax():
        return TemplateResponse(
            request,
            "wagtail_embed_videos/embed_videos/results.html",
            {
                "embed_videos": embed_videos,
                "query_string": query_string,
                "is_searching": bool(query_string),
            },
        )
    else:
        return TemplateResponse(
            request,
            "wagtail_embed_videos/embed_videos/index.html",
            {
                "embed_videos": embed_videos,
                "query_string": query_string,
                "is_searching": bool(query_string),
                "search_form": form,
                "popular_tags": popular_tags_for_model(EmbedVideo),
                "current_tag": current_tag,
                "collections": collections,
                "current_collection": current_collection,
                "user_can_add": permission_policy.user_has_permission(request.user, "add"),
            },
        )


@permission_checker.require("change")
def edit(request, embed_video_id):
    EmbedVideo = get_embed_video_model()
    EmbedVideoForm = get_embed_video_form(EmbedVideo)

    embed_video = get_object_or_404(EmbedVideo, id=embed_video_id)

    if not permission_policy.user_has_permission_for_instance(request.user, "change", embed_video):
        return permission_denied(request)

    if request.method == "POST":
        form = EmbedVideoForm(request.POST, request.FILES, instance=embed_video, user=request.user)
        if form.is_valid():
            form.save()

            # Reindex the embed video to make sure all tags are indexed
            search_index.insert_or_update_object(embed_video)

            messages.success(
                request,
                _("Video '{0}' updated.").format(embed_video.title),
                buttons=[
                    messages.button(reverse("wagtail_embed_videos:edit", args=(embed_video.id,)), _("Edit again"))
                ],
            )
            return redirect("wagtail_embed_videos:index")
        else:
            messages.error(request, _("The video could not be saved due to errors."))
    else:
        form = EmbedVideoForm(instance=embed_video, user=request.user)

    return TemplateResponse(
        request,
        "wagtail_embed_videos/embed_videos/edit.html",
        {
            "embed_video": embed_video,
            "form": form,
            "user_can_delete": permission_policy.user_has_permission_for_instance(request.user, "delete", embed_video),
        },
    )


@permission_checker.require("delete")
def delete(request, embed_video_id):
    embed_video = get_object_or_404(get_embed_video_model(), id=embed_video_id)

    if not permission_policy.user_has_permission_for_instance(request.user, "delete", embed_video):
        return permission_denied(request)

    if request.method == "POST":
        embed_video.delete()
        messages.success(request, _("Video '{0}' deleted.").format(embed_video.title))
        return redirect("wagtail_embed_videos:index")

    return TemplateResponse(
        request,
        "wagtail_embed_videos/embed_videos/confirm_delete.html",
        {
            "embed_video": embed_video,
        },
    )


@permission_checker.require("add")
def add(request):
    EmbedVideo = get_embed_video_model()
    EmbedVideoForm = get_embed_video_form(EmbedVideo)

    if request.method == "POST":
        embed_video = EmbedVideo(uploaded_by_user=request.user)
        form = EmbedVideoForm(request.POST, request.FILES, instance=embed_video, user=request.user)
        if form.is_valid():
            form.save()

            # Reindex the embed video to make sure all tags are indexed
            search_index.insert_or_update_object(embed_video)

            messages.success(
                request,
                _("Video '{0}' added.").format(embed_video.title),
                buttons=[messages.button(reverse("wagtail_embed_videos:edit", args=(embed_video.id,)), _("Edit"))],
            )
            return redirect("wagtail_embed_videos:index")
        else:
            messages.error(request, _("The video could not be created due to errors."))
    else:
        form = EmbedVideoForm(user=request.user)

    return TemplateResponse(
        request,
        "wagtail_embed_videos/embed_videos/add.html",
        {
            "form": form,
        },
    )


def usage(request, embed_video_id):
    embed_video = get_object_or_404(get_embed_video_model(), id=embed_video_id)

    paginator = Paginator(embed_video.get_usage(), per_page=USAGE_PAGE_SIZE)
    used_by = paginator.get_page(request.GET.get("p"))

    return TemplateResponse(
        request, "wagtail_embed_videos/embed_videos/usage.html", {"embed_video": embed_video, "used_by": used_by}
    )



from django.conf import settings
from django.core.paginator import Paginator
from django.shortcuts import get_object_or_404
from django.template.response import TemplateResponse
from django.urls import reverse
from django.utils.translation import gettext as _
from embed_video.backends import detect_backend
from wagtail.admin.forms.search import SearchForm
from wagtail.admin.modal_workflow import render_modal_workflow
from wagtail.admin.auth import PermissionPolicyChecker
from wagtail.admin.models import popular_tags_for_model
from wagtail.core import hooks
from wagtail.core.models import Collection
from wagtail.search import index as search_index

from wagtail_embed_videos import get_embed_video_model
from wagtail_embed_videos.forms import get_embed_video_form
from wagtail_embed_videos.permissions import permission_policy

permission_checker = PermissionPolicyChecker(permission_policy)

CHOOSER_PAGE_SIZE = getattr(settings, "WAGTAILEMBEDVIDEOS_CHOOSER_PAGE_SIZE", 12)


def get_chooser_js_data():
    """construct context variables needed by the chooser JS"""
    return {
        "step": "chooser",
        "error_label": _("Server Error"),
        "error_message": _("Report this error to your webmaster with the following information:"),
        "tag_autocomplete_url": reverse("wagtailadmin_tag_autocomplete"),
    }


def get_embed_video_result_data(embed_video):
    """
    helper function: given embed video, return the json data to pass back to the
    embed video chooser panel
    """
    if embed_video.thumbnail:
        preview_url = embed_video.thumbnail.get_rendition("max-165x165").url
    else:
        preview_url = detect_backend(embed_video.url).get_thumbnail_url()

    return {
        "id": embed_video.id,
        "edit_link": reverse("wagtail_embed_videos:edit", args=(embed_video.id,)),
        "title": embed_video.title,
        "preview": {
            "url": preview_url,
        },
    }


def get_chooser_context(request):
    """Helper function to return common template context variables for the main chooser view"""

    collections = Collection.objects.all()
    if len(collections) < 2:
        collections = None
    else:
        collections = Collection.order_for_display(collections)

    return {
        "searchform": SearchForm(),
        "is_searching": False,
        "query_string": None,
        "popular_tags": popular_tags_for_model(get_embed_video_model()),
        "collections": collections,
    }


def chooser(request):
    EmbedVideo = get_embed_video_model()

    if permission_policy.user_has_permission(request.user, "add"):
        EmbedVideoForm = get_embed_video_form(EmbedVideo)
        uploadform = EmbedVideoForm(user=request.user)
    else:
        uploadform = None

    embed_videos = EmbedVideo.objects.order_by("-created_at")

    # allow hooks to modify the queryset
    for hook in hooks.get_hooks("construct_embed_video_chooser_queryset"):
        embed_videos = hook(embed_videos, request)

    if "q" in request.GET or "p" in request.GET or "tag" in request.GET or "collection_id" in request.GET:
        # this request is triggered from search, pagination or 'popular tags';
        # we will just render the results.html fragment
        collection_id = request.GET.get("collection_id")
        if collection_id:
            embed_videos = embed_videos.filter(collection=collection_id)

        searchform = SearchForm(request.GET)
        if searchform.is_valid():
            q = searchform.cleaned_data["q"]

            embed_videos = embed_videos.search(q)
            is_searching = True
        else:
            is_searching = False
            q = None

            tag_name = request.GET.get("tag")
            if tag_name:
                embed_videos = embed_videos.filter(tags__name=tag_name)

        # Pagination
        paginator = Paginator(embed_videos, per_page=CHOOSER_PAGE_SIZE)
        embed_videos = paginator.get_page(request.GET.get("p"))

        return TemplateResponse(
            request,
            "wagtail_embed_videos/chooser/results.html",
            {
                "embed_videos": embed_videos,
                "is_searching": is_searching,
                "query_string": q,
            },
        )
    else:
        paginator = Paginator(embed_videos, per_page=CHOOSER_PAGE_SIZE)
        embed_videos = paginator.get_page(request.GET.get("p"))

        context = get_chooser_context(request)
        context.update(
            {
                "embed_videos": embed_videos,
                "uploadform": uploadform,
            }
        )
        return render_modal_workflow(
            request, "wagtail_embed_videos/chooser/chooser.html", None, context, json_data=get_chooser_js_data()
        )


def embed_video_chosen(request, embed_video_id):
    embed_video = get_object_or_404(get_embed_video_model(), id=embed_video_id)

    return render_modal_workflow(
        request,
        None,
        None,
        None,
        json_data={"step": "embed_video_chosen", "result": get_embed_video_result_data(embed_video)},
    )


@permission_checker.require("add")
def chooser_upload(request):
    EmbedVideo = get_embed_video_model()
    EmbedVideoForm = get_embed_video_form(EmbedVideo)

    if request.method == "POST":
        embed_video = EmbedVideo(uploaded_by_user=request.user)
        form = EmbedVideoForm(
            request.POST, request.FILES, instance=embed_video, user=request.user, prefix="embed_video-chooser-upload"
        )

        if form.is_valid():
            form.save()

            # Reindex the embed video to make sure all tags are indexed
            search_index.insert_or_update_object(embed_video)

            return render_modal_workflow(
                request,
                None,
                None,
                None,
                json_data={"step": "embed_video_chosen", "result": get_embed_video_result_data(embed_video)},
            )
    else:
        form = EmbedVideoForm(user=request.user, prefix="embed_video-chooser-upload")

    embed_videos = EmbedVideo.objects.order_by("-created_at")

    # allow hooks to modify the queryset
    for hook in hooks.get_hooks("construct_embed_video_chooser_queryset"):
        embed_videos = hook(embed_videos, request)

    paginator = Paginator(embed_videos, per_page=CHOOSER_PAGE_SIZE)
    embed_videos = paginator.get_page(request.GET.get("p"))

    context = get_chooser_context(request)
    context.update(
        {
            "embed_videos": embed_videos,
            "uploadform": form,
        }
    )
    return render_modal_workflow(
        request, "wagtail_embed_videos/chooser/chooser.html", None, context, json_data=get_chooser_js_data()
    )



from django.urls import include, path, reverse
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _
from django.utils.translation import gettext, ngettext
from wagtail.admin.menu import MenuItem
from wagtail.admin.search import SearchArea
# from wagtail.admin.site_summary import SummaryItem
from wagtail.core import hooks

from wagtail_embed_videos import admin_urls, get_embed_video_model
from wagtail_embed_videos.forms import GroupEmbedVideoPermissionFormSet
from wagtail_embed_videos.permissions import permission_policy


@hooks.register("register_admin_urls")
def register_admin_urls():
    return [
        path("embed_videos/", include(admin_urls, namespace="wagtail_embed_videos")),
    ]


@hooks.register("construct_main_menu")
def construct_main_menu(request, menu_items):
    # TODO: register endpoint
    pass


class EmbedVideosMenuItem(MenuItem):
    def is_shown(self, request):
        return permission_policy.user_has_any_permission(request.user, ["add", "change", "delete"])


@hooks.register("register_admin_menu_item")
def register_embedvideos_menu_item():
    return EmbedVideosMenuItem(
        _("Embed Videos"),
        reverse("wagtail_embed_videos:index"),
        name="embedvideos",
        icon_name="media",
        order=301,
    )


@hooks.register("insert_editor_js")
def editor_js():
    return format_html(
        """
        <script>
            window.chooserUrls.embedVideoChooser = '{0}';
        </script>
        """,
        reverse("wagtail_embed_videos:chooser"),
    )


# TODO: implement register_embedvideo_feature

# class EmbedVideosSummaryItem(SummaryItem):
#     order = 201
#     template = "wagtail_embed_videos/homepage/site_summary_videos.html"

#     def get_context(self):
#         return {
#             "total_videos": get_embed_video_model().objects.count(),
#         }

#     def is_shown(self):
#         return permission_policy.user_has_any_permission(self.request.user, ["add", "change", "delete"])


# @hooks.register("construct_homepage_summary_items")
# def add_embed_videos_summary_item(request, items):
#     items.append(EmbedVideosSummaryItem(request))


class EmbedVideosSearchArea(SearchArea):
    def is_shown(self, request):
        return permission_policy.user_has_any_permission(request.user, ["add", "change", "delete"])


@hooks.register("register_admin_search_area")
def register_embedvideos_search_area():
    return EmbedVideosSearchArea(
        _("Embed Videos"),
        reverse("wagtail_embed_videos:index"),
        name="embedvideos",
        classnames="icon icon-media",
        order=201,
    )


@hooks.register("register_group_permission_panel")
def register_embedvideo_permissions_panel():
    return GroupEmbedVideoPermissionFormSet


@hooks.register("describe_collection_contents")
def describe_collection_docs(collection):
    embedvideos_count = get_embed_video_model().objects.filter(collection=collection).count()
    if embedvideos_count:
        url = reverse("wagtail_embed_videos:index") + ("?collection_id=%d" % collection.id)
        return {
            "count": embedvideos_count,
            "count_text": ngettext("%(count)s embed video", "%(count)s embed videos", embedvideos_count)
            % {"count": embedvideos_count},
            "url": url,
        }



import os

WAGTAIL_ROOT = os.path.dirname(__file__)
STATIC_ROOT = os.path.join(WAGTAIL_ROOT, "test-static")
MEDIA_ROOT = os.path.join(WAGTAIL_ROOT, "test-media")
MEDIA_URL = "/media/"


DATABASES = {
    "default": {
        "ENGINE": os.environ.get("DATABASE_ENGINE", "django.db.backends.sqlite3"),
        "NAME": os.environ.get("DATABASE_NAME", "wagtail"),
        "USER": os.environ.get("DATABASE_USER", None),
        "PASSWORD": os.environ.get("DATABASE_PASS", None),
        "HOST": os.environ.get("DATABASE_HOST", None),
        "TEST": {
            "NAME": os.environ.get("DATABASE_NAME", None),
        },
    }
}


SECRET_KEY = "not needed"

ROOT_URLCONF = "wagtail.tests.urls"

STATIC_URL = "/static/"
STATIC_ROOT = STATIC_ROOT

STATICFILES_FINDERS = (
    "django.contrib.staticfiles.finders.AppDirectoriesFinder",
    "compressor.finders.CompressorFinder",
)

USE_TZ = True

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "django.template.context_processors.request",
                "wagtail.tests.context_processors.do_not_use_static_url",
                "wagtail.contrib.settings.context_processors.settings",
            ],
        },
    },
    {
        "BACKEND": "django.template.backends.jinja2.Jinja2",
        "APP_DIRS": True,
        "OPTIONS": {
            "extensions": [
                "wagtail.core.jinja2tags.core",
                "wagtail.admin.jinja2tags.userbar",
                "wagtail.images.jinja2tags.images",
            ],
        },
    },
]

MIDDLEWARE_CLASSES = (
    "django.middleware.common.CommonMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.auth.middleware.SessionAuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "wagtail.core.middleware.SiteMiddleware",
    "wagtail.redirects.middleware.RedirectMiddleware",
)

INSTALLED_APPS = (
    # Install wagtailredirects with its appconfig
    # Theres nothing special about wagtailredirects, we just need to have one
    # app which uses AppConfigs to test that hooks load properly
    "wagtail.forms",
    "wagtail.redirects",
    "wagtail.embeds",
    "wagtail.sites",
    "wagtail.users",
    "wagtail.snippets",
    "wagtail.docs",
    "wagtail.images",
    "wagtail.search",
    "wagtail.admin",
    "wagtail.core",
    "wagtail.contrib.wagtailapi",
    "modelcluster",
    "compressor",
    "taggit",
    "rest_framework",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "embed_video",
    "wagtail_embed_videos",
)


# Using DatabaseCache to make sure that the cache is cleared between tests.
# This prevents false-positives in some wagtail core tests where we are
# changing the 'wagtail_root_paths' key which may cause future tests to fail.
CACHES = {
    "default": {
        "BACKEND": "django.core.cache.backends.db.DatabaseCache",
        "LOCATION": "cache",
    }
}

PASSWORD_HASHERS = (
    "django.contrib.auth.hashers.MD5PasswordHasher",  # don't use the intentionally slow default password hasher
)

COMPRESS_ENABLED = False  # disable compression so that we can run tests on the content of the compress tag


WAGTAILSEARCH_BACKENDS = {
    "default": {
        "BACKEND": "wagtail.search.backends.db",
    }
}

if "ELASTICSEARCH_URL" in os.environ:
    WAGTAILSEARCH_BACKENDS["elasticsearch"] = {
        "BACKEND": "wagtail.search.backends.elasticsearch",
        "URLS": [os.environ["ELASTICSEARCH_URL"]],
        "TIMEOUT": 10,
        "max_retries": 1,
        "AUTO_UPDATE": False,
    }


WAGTAIL_SITE_NAME = "Test Site"



# Generated by Django 2.2.24 on 2021-11-03 08:02

from django.db import migrations


def get_embedvideo_permissions(apps):
    # return a queryset of the 'add_embedvideo' and 'change_embedvideo' permissions
    Permission = apps.get_model("auth.Permission")
    ContentType = apps.get_model("contenttypes.ContentType")

    embedvideo_content_type, _created = ContentType.objects.get_or_create(
        model="embedvideo",
        app_label="wagtail_embed_videos",
    )
    return Permission.objects.filter(
        content_type=embedvideo_content_type, codename__in=["add_embedvideo", "change_embedvideo"]
    )


def copy_embedvideo_permissions_to_collections(apps, schema_editor):
    Collection = apps.get_model("wagtailcore.Collection")
    Group = apps.get_model("auth.Group")
    GroupCollectionPermission = apps.get_model("wagtailcore.GroupCollectionPermission")

    root_collection = Collection.objects.get(depth=1)

    for permission in get_embedvideo_permissions(apps):
        for group in Group.objects.filter(permissions=permission):
            GroupCollectionPermission.objects.create(group=group, collection=root_collection, permission=permission)


def remove_embedvideo_permissions_from_collections(apps, schema_editor):
    GroupCollectionPermission = apps.get_model("wagtailcore.GroupCollectionPermission")
    embedvideo_permissions = get_embedvideo_permissions(apps)

    GroupCollectionPermission.objects.filter(permission__in=embedvideo_permissions).delete()


class Migration(migrations.Migration):

    dependencies = [
        ("wagtail_embed_videos", "0004_auto_20211103_0746"),
    ]

    operations = [
        migrations.RunPython(
            copy_embedvideo_permissions_to_collections, remove_embedvideo_permissions_from_collections
        ),
    ]



import json

from django import forms
from django.template.loader import render_to_string
from django.utils.translation import gettext_lazy as _
from wagtail.admin.staticfiles import versioned_static
from wagtail.admin.widgets import AdminChooser

from wagtail_embed_videos import get_embed_video_model


class AdminEmbedVideoChooser(AdminChooser):
    choose_one_text = _("Choose an embed video")
    choose_another_text = _("Choose another embed video")
    link_to_chosen_text = _("Edit this embed video")

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.embed_video_model = get_embed_video_model()

    def render_html(self, name, value, attrs):
        instance, value = self.get_instance_and_id(self.embed_video_model, value)
        original_field_html = super().render_html(name, value, attrs)

        return render_to_string(
            "wagtail_embed_videos/widgets/embed_video_chooser.html",
            {
                "widget": self,
                "original_field_html": original_field_html,
                "attrs": attrs,
                "value": value,
                "embed_video": instance,
            },
        )

    def render_js_init(self, id_, name, value):
        return "createEmbedVideoChooser({0});".format(json.dumps(id_))

    @property
    def media(self):
        return forms.Media(
            js=[
                versioned_static("wagtail_embed_videos/js/embed-video-chooser-modal.js"),
                versioned_static("wagtail_embed_videos/js/embed-video-chooser.js"),
            ],
            css={
                "all": (versioned_static("wagtail_embed_videos/css/embed-video-chooser.css"),),
            },
        )
